==> SemanticWeb-Schema-v11.01.0.tar.gz: SemanticWeb-Schema-v11.01.0/lib/SemanticWeb/Schema/EUEnergyEfficiencyEnumeration.pm <==
use utf8;

package SemanticWeb::Schema::EUEnergyEfficiencyEnumeration;

# ABSTRACT: Enumerates the EU energy efficiency classes A-G as well as A+

use Moo;

extends qw/ SemanticWeb::Schema::EnergyEfficiencyEnumeration /;


use MooX::JSON_LD 'EUEnergyEfficiencyEnumeration';
use Ref::Util qw/ is_plain_hashref /;
# RECOMMEND PREREQ: Ref::Util::XS

use namespace::autoclean;

our $VERSION = 'v11.01.0';




1;

__END__

=pod

=encoding UTF-8

=head1 NAME

SemanticWeb::Schema::EUEnergyEfficiencyEnumeration - Enumerates the EU energy efficiency classes A-G as well as A+

=head1 VERSION

version v11.01.0

=head1 DESCRIPTION

Enumerates the EU energy efficiency classes A-G as well as A+, A++, and
A+++ as defined in EU directive 2017/1369

=head1 SEE ALSO

L<SemanticWeb::Schema::EnergyEfficiencyEnumeration>

=head1 SOURCE

The development version is on github at L<https://github.com/robrwo/SemanticWeb-Schema>
and may be cloned from L<git://github.com/robrwo/SemanticWeb-Schema.git>

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website
L<https://github.com/robrwo/SemanticWeb-Schema/issues>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

Robert Rothenberg <rrwo@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018-2020 by Robert Rothenberg.

This is free software, licensed under:

  The Artistic License 2.0 (GPL Compatible)

=cut

==> SemanticWeb-Schema-v12.0.0.tar.gz: SemanticWeb-Schema-v12.0.0/lib/SemanticWeb/Schema/EUEnergyEfficiencyEnumeration.pm <==
use utf8;

package SemanticWeb::Schema::EUEnergyEfficiencyEnumeration;

# ABSTRACT: Enumerates the EU energy efficiency classes A-G as well as A+

use Moo;

extends qw/ SemanticWeb::Schema::EnergyEfficiencyEnumeration /;


use MooX::JSON_LD 'EUEnergyEfficiencyEnumeration';
use Ref::Util qw/ is_plain_hashref /;
# RECOMMEND PREREQ: Ref::Util::XS

use namespace::autoclean;

our $VERSION = 'v12.0.0';




1;

__END__

=pod

=encoding UTF-8

=head1 NAME

SemanticWeb::Schema::EUEnergyEfficiencyEnumeration - Enumerates the EU energy efficiency classes A-G as well as A+

=head1 VERSION

version v12.0.0

=head1 DESCRIPTION

Enumerates the EU energy efficiency classes A-G as well as A+, A++, and
A+++ as defined in EU directive 2017/1369.

=head1 SEE ALSO

L<SemanticWeb::Schema::EnergyEfficiencyEnumeration>

=head1 SOURCE

The development version is on github at L<https://github.com/robrwo/SemanticWeb-Schema>
and may be cloned from L<git://github.com/robrwo/SemanticWeb-Schema.git>

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website
L<https://github.com/robrwo/SemanticWeb-Schema/issues>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

Robert Rothenberg <rrwo@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018-2021 by Robert Rothenberg.

This is free software, licensed under:

  The Artistic License 2.0 (GPL Compatible)

=cut
